summaryrefslogtreecommitdiff
path: root/usr.bin/sndiod/sock.h
diff options
context:
space:
mode:
Diffstat (limited to 'usr.bin/sndiod/sock.h')
-rw-r--r--usr.bin/sndiod/sock.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/usr.bin/sndiod/sock.h b/usr.bin/sndiod/sock.h
index 94d23f21598..ccf00345c54 100644
--- a/usr.bin/sndiod/sock.h
+++ b/usr.bin/sndiod/sock.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: sock.h,v 1.1 2012/11/23 07:03:28 ratchov Exp $ */
+/* $OpenBSD: sock.h,v 1.2 2012/11/30 20:48:00 ratchov Exp $ */
/*
* Copyright (c) 2008-2012 Alexandre Ratchov <alex@caoua.org>
*
@@ -58,7 +58,8 @@ struct sock {
int lastvol; /* last volume */
struct opt *opt; /* "subdevice" definition */
struct slot *slot; /* audio device slot number */
- struct midi *midi; /* midi endpoint number */
+ struct midi *midi; /* midi endpoint */
+ struct port *port; /* midi port */
char who[12]; /* label, mostly for debugging */
};